@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -53,9 +53,7 @@ ImportMailPluginManager *ImportMailPluginManager::self()
 
 bool ImportMailPluginManager::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("importwizard"), [](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(QLatin1String("ImportWizard/PluginMailImporter"));
-    });
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("importwizard"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
