@@ -20,8 +20,8 @@
 #include "clawsmailsettings.h"
 #include <ImportWizard/ImportWizardUtil>
 
-#include <mailtransport/transportmanager.h>
-#include "MailCommon/MailUtil"
+#include <MailTransport/TransportManager>
+#include <MailCommon/MailUtil>
 
 #include <KIdentityManagement/kidentitymanagement/identity.h>
 #include <KIdentityManagement/kidentitymanagement/signature.h>
