@@ -19,8 +19,8 @@
 
 #include "sylpheedsettings.h"
 #include "sylpheedsettingsutils.h"
-#include <mailtransport/transportmanager.h>
-#include "MailCommon/MailUtil"
+#include <MailTransport/TransportManager>
+#include <MailCommon/MailUtil>
 #include <QFileInfo>
 
 #include <KIdentityManagement/kidentitymanagement/identity.h>
