@@ -18,8 +18,8 @@
 */
 
 #include "thunderbirdsettings.h"
-#include <mailtransport/transportmanager.h>
-#include "MailCommon/MailUtil"
+#include <MailTransport/TransportManager>
+#include <MailCommon/MailUtil>
 #include <ImportWizard/ImportWizardUtil>
 
 
